# IMPORTATION STANDARD
import datetime
import logging
from typing import Dict, Union

# IMPORTATION THIRD PARTY
import requests
from google.protobuf import json_format

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import (
    Credentials,
    TransactionsHistory,
)


class ActionGetTransactionsHistory(AbstractAction):
    @staticmethod
    def transactions_history_request_to_api(
        request: TransactionsHistory.Request,
    ) -> dict:
        request_dict = dict()
        request_dict["fromDate"] = datetime.datetime(
            year=request.from_date.year,
            month=request.from_date.month,
            day=request.from_date.day,
        ).strftime("%d/%m/%Y")
        request_dict["toDate"] = datetime.datetime(
            year=request.to_date.year,
            month=request.to_date.month,
            day=request.to_date.day,
        ).strftime("%d/%m/%Y")

        return request_dict

    @staticmethod
    def transactions_history_to_grpc(payload: dict) -> TransactionsHistory:
        transactions_history = TransactionsHistory()
        transactions_history.response_datetime.GetCurrentTime()
        json_format.ParseDict(
            js_dict={"values": payload["data"]},
            message=transactions_history,
            ignore_unknown_fields=True,
            descriptor_pool=None,
        )

        return transactions_history

    @classmethod
    def get_transactions_history(
        cls,
        request: TransactionsHistory.Request,
        session_id: str,
        credentials: Credentials,
        raw: bool = False,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Union[TransactionsHistory, Dict, None]:
        """Retrieve history about transactions.
        Args:
            request (TransactionsHistory.Request):
                List of options that we want to retrieve from the endpoint.
                Example :
                    from_date = TransactionsHistory.Request.Date(
                        year=2020,
                        month=10,
                        day=15,
                    )
                    from_date = TransactionsHistory.Request.Date(
                        year=2020,
                        month=10,
                        day=16,
                    )
                    request = TransactionsHistory.Request(
                        from_date=from_date,
                        to_date=to_date,
                    )
            session_id (str):
                API's session id.
            credentials (Credentials):
                Credentials containing the parameter "int_account".
            raw (bool, optional):
                Whether are not we want the raw API response.
                Defaults to False.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Returns:
            TransactionsHistory: API response.
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = urls.TRANSACTIONS_HISTORY

        params = cls.transactions_history_request_to_api(
            request=request,
        )
        params["intAccount"] = credentials.int_account
        params["sessionId"] = session_id

        http_request = requests.Request(method="GET", url=url, params=params)
        prepped = session.prepare_request(http_request)
        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()

            if raw is True:
                return response_dict
            else:
                return cls.transactions_history_to_grpc(
                    payload=response_dict,
                )
        except requests.HTTPError as e:
            status_code = getattr(response_raw, "status_code", "No status_code found.")
            text = getattr(response_raw, "text", "No text found.")
            logger.fatal(status_code)
            logger.fatal(text)
            return None
        except Exception as e:
            logger.fatal(e)
            return None

    def call(
        self,
        request: TransactionsHistory.Request,
        raw: bool = False,
    ) -> Union[TransactionsHistory, Dict, None]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        return self.get_transactions_history(
            request=request,
            session_id=session_id,
            credentials=credentials,
            raw=raw,
            session=session,
            logger=logger,
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Metadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESPONSE_DATETIME_FIELD_NUMBER: builtins.int
    REQUEST_DURATION_FIELD_NUMBER: builtins.int
    @property
    def response_datetime(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def request_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(self,
        *,
        response_datetime : typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        request_duration : typing.Optional[google.protobuf.duration_pb2.Duration] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"request_duration",b"request_duration",u"response_datetime",b"response_datetime"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"request_duration",b"request_duration",u"response_datetime",b"response_datetime"]) -> None: ...
global___Metadata = Metadata

class Quotecast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class SubscriptionsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: typing.Text = ...
            @property
            def value(self) -> google.protobuf.struct_pb2.ListValue: ...
            def __init__(self,
                *,
                key : typing.Text = ...,
                value : typing.Optional[google.protobuf.struct_pb2.ListValue] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

        class UnsubscriptionsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: typing.Text = ...
            @property
            def value(self) -> google.protobuf.struct_pb2.ListValue: ...
            def __init__(self,
                *,
                key : typing.Text = ...,
                value : typing.Optional[google.protobuf.struct_pb2.ListValue] = ...,
                ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

        SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
        UNSUBSCRIPTIONS_FIELD_NUMBER: builtins.int
        @property
        def subscriptions(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, google.protobuf.struct_pb2.ListValue]:
            """<vwd_id, metrics>"""
            pass
        @property
        def unsubscriptions(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, google.protobuf.struct_pb2.ListValue]:
            """<vwd_id, metrics>"""
            pass
        def __init__(self,
            *,
            subscriptions : typing.Optional[typing.Mapping[typing.Text, google.protobuf.struct_pb2.ListValue]] = ...,
            unsubscriptions : typing.Optional[typing.Mapping[typing.Text, google.protobuf.struct_pb2.ListValue]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"subscriptions",b"subscriptions",u"unsubscriptions",b"unsubscriptions"]) -> None: ...

    JSON_DATA_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    json_data: typing.Text = ...
    """PROPERTIES"""

    @property
    def metadata(self) -> global___Metadata: ...
    def __init__(self,
        *,
        json_data : typing.Text = ...,
        metadata : typing.Optional[global___Metadata] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"json_data",b"json_data",u"metadata",b"metadata"]) -> None: ...
global___Quotecast = Quotecast

class Ticker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Metrics(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class MetricsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: typing.Text = ...
            value: builtins.float = ...
            def __init__(self,
                *,
                key : typing.Text = ...,
                value : builtins.float = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

        METRICS_FIELD_NUMBER: builtins.int
        @property
        def metrics(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.float]:
            """<metric_name, metric_value>"""
            pass
        def __init__(self,
            *,
            metrics : typing.Optional[typing.Mapping[typing.Text, builtins.float]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"metrics",b"metrics"]) -> None: ...

    class ProductsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...
        @property
        def value(self) -> global___Ticker.Metrics: ...
        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[global___Ticker.Metrics] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    PRODUCTS_FIELD_NUMBER: builtins.int
    PRODUCT_LIST_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> global___Metadata:
        """PROPERTIES"""
        pass
    @property
    def products(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Ticker.Metrics]:
        """<vwd_id, metrics>"""
        pass
    @property
    def product_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        metadata : typing.Optional[global___Metadata] = ...,
        products : typing.Optional[typing.Mapping[typing.Text, global___Ticker.Metrics]] = ...,
        product_list : typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"metadata",b"metadata",u"product_list",b"product_list",u"products",b"products"]) -> None: ...
global___Ticker = Ticker

class Chart(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class Interval(_Interval, metaclass=_IntervalEnumTypeWrapper):
        """ENUMS"""
        pass
    class _Interval:
        V = typing.NewType('V', builtins.int)
    class _IntervalEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Interval.V], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        PT1S = Chart.Interval.V(0)
        PT15S = Chart.Interval.V(1)
        PT30S = Chart.Interval.V(2)
        PT1M = Chart.Interval.V(3)
        PT5M = Chart.Interval.V(4)
        PT15M = Chart.Interval.V(5)
        PT30M = Chart.Interval.V(6)
        PT60M = Chart.Interval.V(7)
        PT1H = Chart.Interval.V(8)
        P1D = Chart.Interval.V(9)
        P1W = Chart.Interval.V(10)
        P1M = Chart.Interval.V(11)
        P3M = Chart.Interval.V(12)
        P6M = Chart.Interval.V(13)
        P1Y = Chart.Interval.V(14)
        P3Y = Chart.Interval.V(15)
        P5Y = Chart.Interval.V(16)
        P10Y = Chart.Interval.V(17)
        P50Y = Chart.Interval.V(18)
        YTD = Chart.Interval.V(19)

    PT1S = Chart.Interval.V(0)
    PT15S = Chart.Interval.V(1)
    PT30S = Chart.Interval.V(2)
    PT1M = Chart.Interval.V(3)
    PT5M = Chart.Interval.V(4)
    PT15M = Chart.Interval.V(5)
    PT30M = Chart.Interval.V(6)
    PT60M = Chart.Interval.V(7)
    PT1H = Chart.Interval.V(8)
    P1D = Chart.Interval.V(9)
    P1W = Chart.Interval.V(10)
    P1M = Chart.Interval.V(11)
    P3M = Chart.Interval.V(12)
    P6M = Chart.Interval.V(13)
    P1Y = Chart.Interval.V(14)
    P3Y = Chart.Interval.V(15)
    P5Y = Chart.Interval.V(16)
    P10Y = Chart.Interval.V(17)
    P50Y = Chart.Interval.V(18)
    YTD = Chart.Interval.V(19)

    class Request(google.protobuf.message.Message):
        """MESSAGES"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        class OverrideEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: typing.Text = ...
            value: typing.Text = ...
            def __init__(self,
                *,
                key : typing.Text = ...,
                value : typing.Text = ...,
                ) -> None: ...
            def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

        REQUESTID_FIELD_NUMBER: builtins.int
        RESOLUTION_FIELD_NUMBER: builtins.int
        CULTURE_FIELD_NUMBER: builtins.int
        PERIOD_FIELD_NUMBER: builtins.int
        SERIES_FIELD_NUMBER: builtins.int
        TZ_FIELD_NUMBER: builtins.int
        OVERRIDE_FIELD_NUMBER: builtins.int
        requestid: typing.Text = ...
        resolution: global___Chart.Interval.V = ...
        culture: typing.Text = ...
        period: global___Chart.Interval.V = ...
        @property
        def series(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
        tz: typing.Text = ...
        @property
        def override(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, typing.Text]: ...
        def __init__(self,
            *,
            requestid : typing.Text = ...,
            resolution : global___Chart.Interval.V = ...,
            culture : typing.Text = ...,
            period : global___Chart.Interval.V = ...,
            series : typing.Optional[typing.Iterable[typing.Text]] = ...,
            tz : typing.Text = ...,
            override : typing.Optional[typing.Mapping[typing.Text, typing.Text]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"culture",b"culture",u"override",b"override",u"period",b"period",u"requestid",b"requestid",u"resolution",b"resolution",u"series",b"series",u"tz",b"tz"]) -> None: ...

    class Serie(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        TIMES_FIELD_NUMBER: builtins.int
        EXPIRES_FIELD_NUMBER: builtins.int
        DATA_FIELD_NUMBER: builtins.int
        ID_FIELD_NUMBER: builtins.int
        TYPE_FIELD_NUMBER: builtins.int
        times: typing.Text = ...
        expires: typing.Text = ...
        @property
        def data(self) -> google.protobuf.struct_pb2.ListValue: ...
        id: typing.Text = ...
        type: typing.Text = ...
        def __init__(self,
            *,
            times : typing.Text = ...,
            expires : typing.Text = ...,
            data : typing.Optional[google.protobuf.struct_pb2.ListValue] = ...,
            id : typing.Text = ...,
            type : typing.Text = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"data",b"data"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"data",b"data",u"expires",b"expires",u"id",b"id",u"times",b"times",u"type",b"type"]) -> None: ...

    REQUESTID_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    RESOLUTION_FIELD_NUMBER: builtins.int
    SERIES_FIELD_NUMBER: builtins.int
    requestid: typing.Text = ...
    """PROPERTIES"""

    start: typing.Text = ...
    end: typing.Text = ...
    resolution: typing.Text = ...
    @property
    def series(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Chart.Serie]: ...
    def __init__(self,
        *,
        requestid : typing.Text = ...,
        start : typing.Text = ...,
        end : typing.Text = ...,
        resolution : typing.Text = ...,
        series : typing.Optional[typing.Iterable[global___Chart.Serie]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"end",b"end",u"requestid",b"requestid",u"resolution",b"resolution",u"series",b"series",u"start",b"start"]) -> None: ...
global___Chart = Chart



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import degiro_connector.trading.models.trading_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SetConfig(google.protobuf.message.Message):
    """MESSAGES"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREDENTIALS_FIELD_NUMBER: builtins.int
    AUTO_CONNECT_FIELD_NUMBER: builtins.int
    @property
    def credentials(self) -> degiro_connector.trading.models.trading_pb2.Credentials: ...
    auto_connect: builtins.bool = ...
    def __init__(self,
        *,
        credentials : typing.Optional[degiro_connector.trading.models.trading_pb2.Credentials] = ...,
        auto_connect : builtins.bool = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"credentials",b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auto_connect",b"auto_connect",u"credentials",b"credentials"]) -> None: ...
global___SetConfig = SetConfig

class ConfirmOrder(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONFIRMATION_ID_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    @property
    def confirmation_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def order(self) -> degiro_connector.trading.models.trading_pb2.Order: ...
    def __init__(self,
        *,
        confirmation_id : typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        order : typing.Optional[degiro_connector.trading.models.trading_pb2.Order] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"confirmation_id",b"confirmation_id",u"order",b"order"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"confirmation_id",b"confirmation_id",u"order",b"order"]) -> None: ...
global___ConfirmOrder = ConfirmOrder

class ProductSearch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BONDS_FIELD_NUMBER: builtins.int
    ETFS_FIELD_NUMBER: builtins.int
    FUNDS_FIELD_NUMBER: builtins.int
    FUTURES_FIELD_NUMBER: builtins.int
    LEVERAGEDS_FIELD_NUMBER: builtins.int
    LOOKUP_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    STOCKS_FIELD_NUMBER: builtins.int
    WARRANTS_FIELD_NUMBER: builtins.int
    @property
    def bonds(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestBonds: ...
    @property
    def etfs(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestETFs: ...
    @property
    def funds(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestFunds: ...
    @property
    def futures(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestFutures: ...
    @property
    def leverageds(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestLeverageds: ...
    @property
    def lookup(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestLookup: ...
    @property
    def options(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestOptions: ...
    @property
    def stocks(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestStocks: ...
    @property
    def warrants(self) -> degiro_connector.trading.models.trading_pb2.ProductSearch.RequestWarrants: ...
    def __init__(self,
        *,
        bonds : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestBonds] = ...,
        etfs : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestETFs] = ...,
        funds : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestFunds] = ...,
        futures : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestFutures] = ...,
        leverageds : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestLeverageds] = ...,
        lookup : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestLookup] = ...,
        options : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestOptions] = ...,
        stocks : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestStocks] = ...,
        warrants : typing.Optional[degiro_connector.trading.models.trading_pb2.ProductSearch.RequestWarrants] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"bonds",b"bonds",u"etfs",b"etfs",u"funds",b"funds",u"futures",b"futures",u"leverageds",b"leverageds",u"lookup",b"lookup",u"options",b"options",u"request",b"request",u"stocks",b"stocks",u"warrants",b"warrants"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"bonds",b"bonds",u"etfs",b"etfs",u"funds",b"funds",u"futures",b"futures",u"leverageds",b"leverageds",u"lookup",b"lookup",u"options",b"options",u"request",b"request",u"stocks",b"stocks",u"warrants",b"warrants"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"request",b"request"]) -> typing.Optional[typing_extensions.Literal["bonds","etfs","funds","futures","leverageds","lookup","options","stocks","warrants"]]: ...
global___ProductSearch = ProductSearch



# IMPORTATION STANDARD
from concurrent import futures
from functools import wraps
from typing import Callable, List, Optional
from google.protobuf.internal.well_known_types import Any

# IMPORTATION THIRD PARTY
import grpc
from degiro_connector.quotecast.actions.action_connect import ActionConnect
from google.protobuf import json_format
from google.protobuf.empty_pb2 import Empty
from google.protobuf.struct_pb2 import Struct
from google.protobuf.wrappers_pb2 import (
    BoolValue,
    DoubleValue,
    Int64Value,
    StringValue,
)

# IMPORTATION INTERNAL
from degiro_connector.quotecast.api import API
from degiro_connector.quotecast.models.quotecast_relay_pb2_grpc import (
    add_QuotecastRelayServicer_to_server,
    QuotecastRelayServicer,
)


class Relay(QuotecastRelayServicer):
    OVERRIDED_METHOD_LIST: List[str] = []
    PB_WRAPPERS_PATH = "google/protobuf/wrappers.proto"
    PY_TO_PB_TABLE = {
        bool: BoolValue,
        dict: Struct,
        int: Int64Value,
        float: DoubleValue,
        str: StringValue,
    }

    @classmethod
    def get_service_list(cls):
        service_list = list()

        for attr in dir(cls.__bases__[0]):
            if attr[:2] != "__":
                service_list.append(attr)
        return service_list

    @classmethod
    def pb_to_py(cls, obj) -> Optional[Any]:
        if isinstance(obj, Empty):
            return None
        elif obj.DESCRIPTOR.file.name == cls.PB_WRAPPERS_PATH:
            return obj.value
        else:
            return obj

    @classmethod
    def py_to_pb(cls, obj):
        obj_type = type(obj)
        if obj is None:
            return Empty()
        elif obj_type in cls.PY_TO_PB_TABLE:
            return json_format.ParseDict(
                js_dict=obj,
                message=cls.PY_TO_PB_TABLE[obj_type](),
                ignore_unknown_fields=True,
                descriptor_pool=None,
            )
        else:
            return obj

    def build_service_func(self, action_func: Callable) -> Callable:
        @wraps(action_func)
        def service_func(request, context):
            print("REQUEST : action_func", action_func)
            # print("REQUEST : request", request)
            print("REQUEST : request type", type(request))
            # print("REQUEST: context", context)

            is_action_connect = isinstance(action_func, ActionConnect)
            print("REQUEST : is_action_connect", is_action_connect)
            if not is_action_connect and self.auto_connect:
                connection_storage = self.api.connection_storage
                is_timeout_expired = connection_storage.is_timeout_expired()
                is_connected = connection_storage.connected.is_set()

                # print("REQUEST : self type", type(connection_storage))
                print("REQUEST : is_timeout_expired", is_timeout_expired)
                print("REQUEST : is_connected", is_connected)

                if not is_connected or is_timeout_expired:
                    self.api.connect()

            request_py = self.pb_to_py(obj=request)
            # print("INPUT PY : request_py", request_py)
            print("REQUEST : request_py type", type(request_py))
            if request_py is None:
                response = action_func()
            else:
                response = action_func(request_py)
            response_pb = self.py_to_pb(obj=response)
            # print("RESPONSE", response_pb)
            print("RESPONSE : type", type(response_pb))
            return response_pb

        return service_func

    @property
    def api(self):
        return self._api

    @property
    def auto_connect(self):
        return self._auto_connect

    def __init__(self, auto_connect: bool = False, user_token: int = 0):
        self._api = API(user_token=user_token)
        self._auto_connect = auto_connect
        self._service_list = self.get_service_list()
        self.load_service_list(service_list=self._service_list)

    def load_service(self, service: str):
        action_list = self._api.action_list

        if service in action_list and not service in self.OVERRIDED_METHOD_LIST:
            action_func = getattr(self._api, service)
            service_func = self.build_service_func(action_func=action_func)
            setattr(self, service, service_func)

    def load_service_list(self, service_list: List[str]):
        for service in service_list:
            self.load_service(service=service)

    def serve(self):
        server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
        add_QuotecastRelayServicer_to_server(self, server)
        server.add_insecure_port("[::]:50051")
        server.start()

        print("STARTING :", self.__class__)

        try:
            server.wait_for_termination()
        except KeyboardInterrupt:
            print("KeyboardInterrupt")
            server.stop(grace=0)

    def set_config(self, request, context):
        print("REQUEST :", request)

        user_token = request.user_token
        auto_connect = request.auto_connect
        self._api.credentials["user_token"] = user_token
        self._auto_connect = auto_connect

        print("RESPONSE :", True)
        return BoolValue(value=True)



# IMPORTATION STANDARD
import logging

# IMPORTATION THIRD PARTY
import onetimepass as otp
import requests

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import (
    Credentials,
)


class ActionConnect(AbstractAction):
    @classmethod
    def get_session_id(
        cls,
        credentials: Credentials,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> str:
        """Establish a connection with Degiro's Trading API.
        Args:
            credentials (Credentials):
                credentials.int_account (int)
                    Account unique identifer in Degiro's system.
                    It is optional.
                credentials.password (str)
                    Password used to log in the website.
                    It is mandatory.
                credentials.username (str)
                    Username used to log in the website.
                    It is mandatory.
                credentials.totp_secret is optional.
                    Secret code for Two-factor Authentication (2FA).
                    It is optional.
            session (requests.Session, optional):
                If you one wants to reuse existing "Session" object.
                Defaults to None.
            logger (logging.Logger, optional):
                If you one wants to reuse existing "Logger" object.
                Defaults to None.
        Raises:
            ConnectionError: Connection failed.
        Returns:
            str: Session id
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        if credentials.HasField("oneof_2fa") is True:
            url = urls.LOGIN + "/totp"
            username = credentials.username
            password = credentials.password

            if credentials.HasField("totp_secret_key") is True:
                totp_secret_key = credentials.totp_secret_key
                one_time_password = str(otp.get_totp(totp_secret_key))
            else:
                one_time_password = str(credentials.one_time_password)

            payload_dict = {
                "username": username,
                "password": password,
                "isPassCodeReset": False,
                "isRedirectToMobile": False,
                "queryParams": {},
                "oneTimePassword": one_time_password,
            }
        else:
            url = urls.LOGIN
            username = credentials.username
            password = credentials.password

            payload_dict = {
                "username": username,
                "password": password,
                "isPassCodeReset": False,
                "isRedirectToMobile": False,
                "queryParams": {},
            }

        request = requests.Request(
            method="POST",
            url=url,
            json=payload_dict,
        )
        prepped = session.prepare_request(request)
        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()
        except Exception as e:
            logger.fatal("response_raw:%s", response_raw)
            raise ConnectionError(e)

        logger.info("get_session_id:response_dict: %s", response_dict)

        if "sessionId" in response_dict:
            return response_dict["sessionId"]
        elif "status" in response_dict and response_dict["status"] == 6:
            logger.fatal("response_dict:%s", response_dict)
            raise ConnectionError('2FA is enabled, please provide the "totp_secret".')
        else:
            logger.fatal("response_dict:%s", response_dict)
            raise ConnectionError("No session id returned.")

    def call(self):
        connection_storage = self.connection_storage
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        connection_storage.session_id = self.get_session_id(
            credentials=credentials,
            logger=logger,
            session=session,
        )

        return connection_storage.session_id



import os

from typing import List


""" Migrate from 1.0.10 to 2.0.0

This script will do the following changes :

1/
REPLACE `degiro_connector.quotecast.pb.quotecast_pb2`
WITH    `degiro_connector.quotecast.models.quotecast_pb2`

2/
REPLACE `degiro_connector.quotecast.pb.quotecast_pb2_grpc`
WITH    `degiro_connector.quotecast.models.quotecast_pb2_grpc`

3/
REPLACE `degiro_connector.trading.pb.trading_pb2`
WITH    `degiro_connector.trading.models.trading_pb2`

4/
REPLACE `degiro_connector.trading.pb.trading_pb2_grpc`
WITH    `degiro_connector.trading.models.trading_pb2_grpc`

5/
REPLACE `degiro_connector.quotecast.helpers.pb_handler`
WITH    `degiro_connector.core.helpers.pb_handler`

6/
REPLACE `degiro_connector.trading.helpers.payload_handler`
WITH    `degiro_connector.core.helpers.pb_handler`
"""


def get_files_list(root_path=".") -> List[str]:
    files_list = list()

    for root, directories, files in os.walk(root_path):
        for name in files:
            if (
                name.endswith(".py")
                and ".tox" not in root
                and ".git" not in root
                and ".egg-info" not in root
                and "\\build\\lib" not in root
                and not name.endswith("setup.py")
            ):
                files_list.append(os.path.join(root, name))

    return files_list


def process(files_list: List[str]):
    print("Processing the following files : ")

    for file_path in files_list:
        if os.path.realpath(file_path) != os.path.realpath(__file__):
            with open(file_path, "r+") as f:
                file_source = f.read()
                replace_string = file_source
                replace_string = replace_string.replace(
                    "degiro_connector.quotecast.pb.quotecast_pb2",
                    "degiro_connector.quotecast.models.quotecast_pb2",
                )
                replace_string = replace_string.replace(
                    "degiro_connector.quotecast.pb.quotecast_pb2_grpc",
                    "degiro_connector.quotecast.models.quotecast_pb2_grpc",
                )
                replace_string = replace_string.replace(
                    "degiro_connector.trading.pb.trading_pb2",
                    "degiro_connector.trading.models.trading_pb2",
                )
                replace_string = replace_string.replace(
                    "degiro_connector.trading.pb.trading_pb2_grpc",
                    "degiro_connector.trading.models.trading_pb2_grpc",
                )
                replace_string = replace_string.replace(
                    "degiro_connector.quotecast.helpers.pb_handler",
                    "degiro_connector.core.helpers.pb_handler",
                )
                replace_string = replace_string.replace(
                    "degiro_connector.trading.helpers.payload_handler",
                    "degiro_connector.core.helpers.pb_handler",
                )

                if replace_string != file_source:
                    print("CHANGED   :", file_path)
                    f.seek(0)
                    f.write(replace_string)
                    f.truncate()
                else:
                    print("UNCHANGED :", file_path)


files_list = get_files_list(root_path=".")
process(files_list=files_list)



# IMPORTATION STANDARD
import logging
from typing import Dict, Union

# IMPORTATION THIRD PARTY
import requests

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction


class ActionGetClientDetails(AbstractAction):
    @classmethod
    def get_client_details(
        cls,
        session_id: str,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Union[Dict, None]:
        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = urls.CLIENT_DETAILS

        params = {
            "sessionId": session_id,
        }

        request = requests.Request(method="GET", url=url, params=params)
        prepped = session.prepare_request(request)
        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()
        except requests.HTTPError as e:
            status_code = getattr(response_raw, "status_code", "No status_code found.")
            text = getattr(response_raw, "text", "No text found.")
            logger.fatal(status_code)
            logger.fatal(text)
            return None
        except Exception as e:
            logger.fatal(e)
            return None

        return response_dict

    def call(self) -> Union[Dict, None]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        logger = self.logger

        return self.get_client_details(
            session_id=session_id,
            session=session,
            logger=logger,
        )



# IMPORTATION STANDARD
import logging
from typing import Dict, Optional

# IMPORTATION THIRD PARTY
import requests

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import (
    Credentials,
)


class ActionCreateFavouriteList(AbstractAction):
    @classmethod
    def favorite_list_to_api(cls, name: str) -> Dict[str, str]:
        return {"name":name}

    @classmethod
    def api_to_favorite_list_id(cls, response_dict: Dict[str, int]) -> int:
        return response_dict["data"]

    @classmethod
    def create_favourite_list(
        cls,
        name: str,
        session_id: str,
        credentials: Credentials,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Optional[int]:
        """Create a favourite list.
        Args:
            name (str):
                New name of the favorite list.
            session_id (str):
                API's session id.
            credentials (Credentials):
                Credentials containing the parameter "int_account".
            raw (bool, optional):
                Whether are not we want the raw API response.
                Defaults to False.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Returns:
            Favourites: API response.
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        int_account = credentials.int_account
        url = urls.PRODUCT_FAVOURITES_LISTS

        params = {
            "intAccount": int_account,
            "sessionId": session_id,
        }

        favorite_list_dict = cls.favorite_list_to_api(name=name)

        request = requests.Request(
            method="POST",
            url=url,
            params=params,
            json=favorite_list_dict,
        )
        prepped = session.prepare_request(request)
        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()
            favorite_list_id = cls.api_to_favorite_list_id(response_dict=response_dict)
        except requests.HTTPError as e:
            status_code = getattr(response_raw, "status_code", "No status_code found.")
            text = getattr(response_raw, "text", "No text found.")
            logger.fatal(status_code)
            logger.fatal(text)
            return None
        except Exception as e:
            logger.fatal(e)
            return None

        return favorite_list_id

    def call(
        self,
        name: str,
    ) -> Optional[int]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        return self.create_favourite_list(
            name=name,
            session_id=session_id,
            credentials=credentials,
            session=session,
            logger=logger,
        )



# IMPORTATION STANDARD
import logging
from typing import Optional

# IMPORTATION THIRD PARTY
import requests

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import (
    Credentials,
)


class ActionDeleteFavouriteList(AbstractAction):
    @classmethod
    def delete_favourite_list(
        cls,
        id: int,
        session_id: str,
        credentials: Credentials,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Optional[bool]:
        """Delete a favourite list.
        Args:
            id (int):
                Id of the favorite list.
            session_id (str):
                API's session id.
            credentials (Credentials):
                Credentials containing the parameter "int_account".
            raw (bool, optional):
                Whether are not we want the raw API response.
                Defaults to False.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Returns:
            Favourites: API response.
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        int_account = credentials.int_account
        url = f"{urls.PRODUCT_FAVOURITES_LISTS}/{id}"

        params = {
            "intAccount": int_account,
            "sessionId": session_id,
        }

        request = requests.Request(method="DELETE", url=url, params=params)
        prepped = session.prepare_request(request)
        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
        except requests.HTTPError as e:
            status_code = getattr(response_raw, "status_code", "No status_code found.")
            text = getattr(response_raw, "text", "No text found.")
            logger.fatal(status_code)
            logger.fatal(text)
            return None
        except Exception as e:
            logger.fatal(e)
            return None

        return response_raw.status_code == 200

    def call(
        self,
        id: int,
    ) -> Optional[bool]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        return self.delete_favourite_list(
            id=id,
            session_id=session_id,
            credentials=credentials,
            session=session,
            logger=logger,
        )



# IMPORTATION STANDARD
import requests
import logging
import json
from typing import Optional

# IMPORTATION THIRD PARTY
# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction


class ActionConnect(AbstractAction):
    @classmethod
    def get_session_id(
        cls,
        user_token: int,
        logger: logging.Logger = None,
        session: requests.Session = None,
    ) -> Optional[str]:
        """Retrieves the "session_id" necessary to access the data-stream.
        Args:
            user_token (int):
                User identifier in Degiro's API.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Returns:
            str: Session id
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = urls.QUOTECAST
        url = f"{url}/request_session"
        version = urls.QUOTECAST_VERSION

        parameters = {"version": version, "userToken": user_token}
        data = '{"referrer":"https://trader.degiro.nl"}'

        request = requests.Request(method="POST", url=url, data=data, params=parameters)
        prepped = session.prepare_request(request=request)

        try:
            response = session.send(request=prepped, verify=False)
            response_dict = json.loads(response.text)
        except Exception as e:
            logger.fatal(e)
            return None

        logger.info("get_session_id:response_dict: %s", response_dict)

        if "sessionId" in response_dict:
            return response_dict["sessionId"]
        else:
            return None

    def call(self) -> Optional[str]:
        connection_storage = self.connection_storage
        session = self.session_storage.session
        credentials = self.credentials
        user_token = credentials["user_token"]
        logger = self.logger

        connection_storage.session_id = self.get_session_id(
            user_token=user_token,
            logger=logger,
            session=session,
        )

        return connection_storage.session_id



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/quotecast/models/quotecast.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='degiro_connector/quotecast/models/quotecast.proto',
  package='degiro_connector.quotecast',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1degiro_connector/quotecast/models/quotecast.proto\x12\x1a\x64\x65giro_connector.quotecast\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"v\n\x08Metadata\x12\x35\n\x11response_datetime\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x10request_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xbe\x03\n\tQuotecast\x12\x11\n\tjson_data\x18\x01 \x01(\t\x12\x36\n\x08metadata\x18\x02 \x01(\x0b\x32$.degiro_connector.quotecast.Metadata\x1a\xe5\x02\n\x07Request\x12W\n\rsubscriptions\x18\x01 \x03(\x0b\x32@.degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry\x12[\n\x0funsubscriptions\x18\x02 \x03(\x0b\x32\x42.degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry\x1aP\n\x12SubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\x1aR\n\x14UnsubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.ListValue:\x02\x38\x01\"\xfd\x02\n\x06Ticker\x12\x36\n\x08metadata\x18\x01 \x01(\x0b\x32$.degiro_connector.quotecast.Metadata\x12\x42\n\x08products\x18\x02 \x03(\x0b\x32\x30.degiro_connector.quotecast.Ticker.ProductsEntry\x12\x14\n\x0cproduct_list\x18\x03 \x03(\t\x1a\x83\x01\n\x07Metrics\x12H\n\x07metrics\x18\x01 \x03(\x0b\x32\x37.degiro_connector.quotecast.Ticker.Metrics.MetricsEntry\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01\x1a[\n\rProductsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.degiro_connector.quotecast.Ticker.Metrics:\x02\x38\x01\"\x85\x06\n\x05\x43hart\x12\x11\n\trequestid\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x0b\n\x03\x65nd\x18\x03 \x01(\t\x12\x12\n\nresolution\x18\x04 \x01(\t\x12\x37\n\x06series\x18\x05 \x03(\x0b\x32\'.degiro_connector.quotecast.Chart.Serie\x1a\xc1\x02\n\x07Request\x12\x11\n\trequestid\x18\x01 \x01(\t\x12>\n\nresolution\x18\x02 \x01(\x0e\x32*.degiro_connector.quotecast.Chart.Interval\x12\x0f\n\x07\x63ulture\x18\x03 \x01(\t\x12:\n\x06period\x18\x04 \x01(\x0e\x32*.degiro_connector.quotecast.Chart.Interval\x12\x0e\n\x06series\x18\x05 \x03(\t\x12\n\n\x02tz\x18\x06 \x01(\t\x12I\n\x08override\x18\x07 \x03(\x0b\x32\x37.degiro_connector.quotecast.Chart.Request.OverrideEntry\x1a/\n\rOverrideEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1ak\n\x05Serie\x12\r\n\x05times\x18\x01 \x01(\t\x12\x0f\n\x07\x65xpires\x18\x02 \x01(\t\x12(\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\xce\x01\n\x08Interval\x12\x08\n\x04PT1S\x10\x00\x12\t\n\x05PT15S\x10\x01\x12\t\n\x05PT30S\x10\x02\x12\x08\n\x04PT1M\x10\x03\x12\x08\n\x04PT5M\x10\x04\x12\t\n\x05PT15M\x10\x05\x12\t\n\x05PT30M\x10\x06\x12\t\n\x05PT60M\x10\x07\x12\x08\n\x04PT1H\x10\x08\x12\x07\n\x03P1D\x10\t\x12\x07\n\x03P1W\x10\n\x12\x07\n\x03P1M\x10\x0b\x12\x07\n\x03P3M\x10\x0c\x12\x07\n\x03P6M\x10\r\x12\x07\n\x03P1Y\x10\x0e\x12\x07\n\x03P3Y\x10\x0f\x12\x07\n\x03P5Y\x10\x10\x12\x08\n\x04P10Y\x10\x11\x12\x08\n\x04P50Y\x10\x12\x12\x07\n\x03YTD\x10\x13\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_CHART_INTERVAL = _descriptor.EnumDescriptor(
  name='Interval',
  full_name='degiro_connector.quotecast.Chart.Interval',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PT1S', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT15S', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT30S', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT1M', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT5M', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT15M', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT30M', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT60M', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PT1H', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P1D', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P1W', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P1M', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P3M', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P6M', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P1Y', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P3Y', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P5Y', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P10Y', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P50Y', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YTD', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1697,
  serialized_end=1903,
)
_sym_db.RegisterEnumDescriptor(_CHART_INTERVAL)


_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='degiro_connector.quotecast.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_datetime', full_name='degiro_connector.quotecast.Metadata.response_datetime', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_duration', full_name='degiro_connector.quotecast.Metadata.request_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=294,
)


_QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY = _descriptor.Descriptor(
  name='SubscriptionsEntry',
  full_name='degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=659,
)

_QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY = _descriptor.Descriptor(
  name='UnsubscriptionsEntry',
  full_name='degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=661,
  serialized_end=743,
)

_QUOTECAST_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.quotecast.Quotecast.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscriptions', full_name='degiro_connector.quotecast.Quotecast.Request.subscriptions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unsubscriptions', full_name='degiro_connector.quotecast.Quotecast.Request.unsubscriptions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY, _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=743,
)

_QUOTECAST = _descriptor.Descriptor(
  name='Quotecast',
  full_name='degiro_connector.quotecast.Quotecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_data', full_name='degiro_connector.quotecast.Quotecast.json_data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='degiro_connector.quotecast.Quotecast.metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUOTECAST_REQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=743,
)


_TICKER_METRICS_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='degiro_connector.quotecast.Ticker.Metrics.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='degiro_connector.quotecast.Ticker.Metrics.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='degiro_connector.quotecast.Ticker.Metrics.MetricsEntry.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1034,
)

_TICKER_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='degiro_connector.quotecast.Ticker.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='degiro_connector.quotecast.Ticker.Metrics.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TICKER_METRICS_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=903,
  serialized_end=1034,
)

_TICKER_PRODUCTSENTRY = _descriptor.Descriptor(
  name='ProductsEntry',
  full_name='degiro_connector.quotecast.Ticker.ProductsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='degiro_connector.quotecast.Ticker.ProductsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='degiro_connector.quotecast.Ticker.ProductsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1127,
)

_TICKER = _descriptor.Descriptor(
  name='Ticker',
  full_name='degiro_connector.quotecast.Ticker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='degiro_connector.quotecast.Ticker.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='products', full_name='degiro_connector.quotecast.Ticker.products', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product_list', full_name='degiro_connector.quotecast.Ticker.product_list', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TICKER_METRICS, _TICKER_PRODUCTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=1127,
)


_CHART_REQUEST_OVERRIDEENTRY = _descriptor.Descriptor(
  name='OverrideEntry',
  full_name='degiro_connector.quotecast.Chart.Request.OverrideEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='degiro_connector.quotecast.Chart.Request.OverrideEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='degiro_connector.quotecast.Chart.Request.OverrideEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1585,
)

_CHART_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='degiro_connector.quotecast.Chart.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requestid', full_name='degiro_connector.quotecast.Chart.Request.requestid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='degiro_connector.quotecast.Chart.Request.resolution', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='culture', full_name='degiro_connector.quotecast.Chart.Request.culture', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='period', full_name='degiro_connector.quotecast.Chart.Request.period', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series', full_name='degiro_connector.quotecast.Chart.Request.series', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tz', full_name='degiro_connector.quotecast.Chart.Request.tz', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override', full_name='degiro_connector.quotecast.Chart.Request.override', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHART_REQUEST_OVERRIDEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1264,
  serialized_end=1585,
)

_CHART_SERIE = _descriptor.Descriptor(
  name='Serie',
  full_name='degiro_connector.quotecast.Chart.Serie',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='times', full_name='degiro_connector.quotecast.Chart.Serie.times', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires', full_name='degiro_connector.quotecast.Chart.Serie.expires', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='degiro_connector.quotecast.Chart.Serie.data', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='degiro_connector.quotecast.Chart.Serie.id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='degiro_connector.quotecast.Chart.Serie.type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1587,
  serialized_end=1694,
)

_CHART = _descriptor.Descriptor(
  name='Chart',
  full_name='degiro_connector.quotecast.Chart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requestid', full_name='degiro_connector.quotecast.Chart.requestid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='degiro_connector.quotecast.Chart.start', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='degiro_connector.quotecast.Chart.end', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resolution', full_name='degiro_connector.quotecast.Chart.resolution', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series', full_name='degiro_connector.quotecast.Chart.series', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHART_REQUEST, _CHART_SERIE, ],
  enum_types=[
    _CHART_INTERVAL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1130,
  serialized_end=1903,
)

_METADATA.fields_by_name['response_datetime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_METADATA.fields_by_name['request_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._LISTVALUE
_QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY.containing_type = _QUOTECAST_REQUEST
_QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY.fields_by_name['value'].message_type = google_dot_protobuf_dot_struct__pb2._LISTVALUE
_QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY.containing_type = _QUOTECAST_REQUEST
_QUOTECAST_REQUEST.fields_by_name['subscriptions'].message_type = _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY
_QUOTECAST_REQUEST.fields_by_name['unsubscriptions'].message_type = _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY
_QUOTECAST_REQUEST.containing_type = _QUOTECAST
_QUOTECAST.fields_by_name['metadata'].message_type = _METADATA
_TICKER_METRICS_METRICSENTRY.containing_type = _TICKER_METRICS
_TICKER_METRICS.fields_by_name['metrics'].message_type = _TICKER_METRICS_METRICSENTRY
_TICKER_METRICS.containing_type = _TICKER
_TICKER_PRODUCTSENTRY.fields_by_name['value'].message_type = _TICKER_METRICS
_TICKER_PRODUCTSENTRY.containing_type = _TICKER
_TICKER.fields_by_name['metadata'].message_type = _METADATA
_TICKER.fields_by_name['products'].message_type = _TICKER_PRODUCTSENTRY
_CHART_REQUEST_OVERRIDEENTRY.containing_type = _CHART_REQUEST
_CHART_REQUEST.fields_by_name['resolution'].enum_type = _CHART_INTERVAL
_CHART_REQUEST.fields_by_name['period'].enum_type = _CHART_INTERVAL
_CHART_REQUEST.fields_by_name['override'].message_type = _CHART_REQUEST_OVERRIDEENTRY
_CHART_REQUEST.containing_type = _CHART
_CHART_SERIE.fields_by_name['data'].message_type = google_dot_protobuf_dot_struct__pb2._LISTVALUE
_CHART_SERIE.containing_type = _CHART
_CHART.fields_by_name['series'].message_type = _CHART_SERIE
_CHART_INTERVAL.containing_type = _CHART
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['Quotecast'] = _QUOTECAST
DESCRIPTOR.message_types_by_name['Ticker'] = _TICKER
DESCRIPTOR.message_types_by_name['Chart'] = _CHART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

Quotecast = _reflection.GeneratedProtocolMessageType('Quotecast', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'SubscriptionsEntry' : _reflection.GeneratedProtocolMessageType('SubscriptionsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY,
      '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Quotecast.Request.SubscriptionsEntry)
      })
    ,

    'UnsubscriptionsEntry' : _reflection.GeneratedProtocolMessageType('UnsubscriptionsEntry', (_message.Message,), {
      'DESCRIPTOR' : _QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY,
      '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Quotecast.Request.UnsubscriptionsEntry)
      })
    ,
    'DESCRIPTOR' : _QUOTECAST_REQUEST,
    '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Quotecast.Request)
    })
  ,
  'DESCRIPTOR' : _QUOTECAST,
  '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Quotecast)
  })
_sym_db.RegisterMessage(Quotecast)
_sym_db.RegisterMessage(Quotecast.Request)
_sym_db.RegisterMessage(Quotecast.Request.SubscriptionsEntry)
_sym_db.RegisterMessage(Quotecast.Request.UnsubscriptionsEntry)

Ticker = _reflection.GeneratedProtocolMessageType('Ticker', (_message.Message,), {

  'Metrics' : _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {

    'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
      'DESCRIPTOR' : _TICKER_METRICS_METRICSENTRY,
      '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Ticker.Metrics.MetricsEntry)
      })
    ,
    'DESCRIPTOR' : _TICKER_METRICS,
    '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Ticker.Metrics)
    })
  ,

  'ProductsEntry' : _reflection.GeneratedProtocolMessageType('ProductsEntry', (_message.Message,), {
    'DESCRIPTOR' : _TICKER_PRODUCTSENTRY,
    '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Ticker.ProductsEntry)
    })
  ,
  'DESCRIPTOR' : _TICKER,
  '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Ticker)
  })
_sym_db.RegisterMessage(Ticker)
_sym_db.RegisterMessage(Ticker.Metrics)
_sym_db.RegisterMessage(Ticker.Metrics.MetricsEntry)
_sym_db.RegisterMessage(Ticker.ProductsEntry)

Chart = _reflection.GeneratedProtocolMessageType('Chart', (_message.Message,), {

  'Request' : _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {

    'OverrideEntry' : _reflection.GeneratedProtocolMessageType('OverrideEntry', (_message.Message,), {
      'DESCRIPTOR' : _CHART_REQUEST_OVERRIDEENTRY,
      '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
      # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Chart.Request.OverrideEntry)
      })
    ,
    'DESCRIPTOR' : _CHART_REQUEST,
    '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Chart.Request)
    })
  ,

  'Serie' : _reflection.GeneratedProtocolMessageType('Serie', (_message.Message,), {
    'DESCRIPTOR' : _CHART_SERIE,
    '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
    # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Chart.Serie)
    })
  ,
  'DESCRIPTOR' : _CHART,
  '__module__' : 'degiro_connector.quotecast.models.quotecast_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.quotecast.Chart)
  })
_sym_db.RegisterMessage(Chart)
_sym_db.RegisterMessage(Chart.Request)
_sym_db.RegisterMessage(Chart.Request.OverrideEntry)
_sym_db.RegisterMessage(Chart.Serie)


_QUOTECAST_REQUEST_SUBSCRIPTIONSENTRY._options = None
_QUOTECAST_REQUEST_UNSUBSCRIPTIONSENTRY._options = None
_TICKER_METRICS_METRICSENTRY._options = None
_TICKER_PRODUCTSENTRY._options = None
_CHART_REQUEST_OVERRIDEENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/quotecast/models/quotecast_relay.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from degiro_connector.quotecast.models import quotecast_pb2 as degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='degiro_connector/quotecast/models/quotecast_relay.proto',
  package='degiro_connector.quotecast_relay',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7degiro_connector/quotecast/models/quotecast_relay.proto\x12 degiro_connector.quotecast_relay\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x31\x64\x65giro_connector/quotecast/models/quotecast.proto\"5\n\tSetConfig\x12\x12\n\nuser_token\x18\x01 \x01(\x05\x12\x14\n\x0c\x61uto_connect\x18\x02 \x01(\x08\x32\xb2\x03\n\x0eQuotecastRelay\x12W\n\nset_config\x12+.degiro_connector.quotecast_relay.SetConfig\x1a\x1a.google.protobuf.BoolValue\"\x00\x12\x41\n\x07\x63onnect\x12\x16.google.protobuf.Empty\x1a\x1c.google.protobuf.StringValue\"\x00\x12M\n\nfetch_data\x12\x16.google.protobuf.Empty\x1a%.degiro_connector.quotecast.Quotecast\"\x00\x12[\n\tget_chart\x12).degiro_connector.quotecast.Chart.Request\x1a!.degiro_connector.quotecast.Chart\"\x00\x12X\n\tsubscribe\x12-.degiro_connector.quotecast.Quotecast.Request\x1a\x1a.google.protobuf.BoolValue\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2.DESCRIPTOR,])




_SETCONFIG = _descriptor.Descriptor(
  name='SetConfig',
  full_name='degiro_connector.quotecast_relay.SetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_token', full_name='degiro_connector.quotecast_relay.SetConfig.user_token', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_connect', full_name='degiro_connector.quotecast_relay.SetConfig.auto_connect', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=258,
)

DESCRIPTOR.message_types_by_name['SetConfig'] = _SETCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetConfig = _reflection.GeneratedProtocolMessageType('SetConfig', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIG,
  '__module__' : 'degiro_connector.quotecast.models.quotecast_relay_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.quotecast_relay.SetConfig)
  })
_sym_db.RegisterMessage(SetConfig)



_QUOTECASTRELAY = _descriptor.ServiceDescriptor(
  name='QuotecastRelay',
  full_name='degiro_connector.quotecast_relay.QuotecastRelay',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=261,
  serialized_end=695,
  methods=[
  _descriptor.MethodDescriptor(
    name='set_config',
    full_name='degiro_connector.quotecast_relay.QuotecastRelay.set_config',
    index=0,
    containing_service=None,
    input_type=_SETCONFIG,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='connect',
    full_name='degiro_connector.quotecast_relay.QuotecastRelay.connect',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='fetch_data',
    full_name='degiro_connector.quotecast_relay.QuotecastRelay.fetch_data',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2._QUOTECAST,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_chart',
    full_name='degiro_connector.quotecast_relay.QuotecastRelay.get_chart',
    index=3,
    containing_service=None,
    input_type=degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2._CHART_REQUEST,
    output_type=degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2._CHART,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='subscribe',
    full_name='degiro_connector.quotecast_relay.QuotecastRelay.subscribe',
    index=4,
    containing_service=None,
    input_type=degiro__connector_dot_quotecast_dot_models_dot_quotecast__pb2._QUOTECAST_REQUEST,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUOTECASTRELAY)

DESCRIPTOR.services_by_name['QuotecastRelay'] = _QUOTECASTRELAY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: degiro_connector/trading/models/trading_relay.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from degiro_connector.trading.models import trading_pb2 as degiro__connector_dot_trading_dot_models_dot_trading__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='degiro_connector/trading/models/trading_relay.proto',
  package='degiro_connector.trading_relay',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3degiro_connector/trading/models/trading_relay.proto\x12\x1e\x64\x65giro_connector.trading_relay\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a-degiro_connector/trading/models/trading.proto\"]\n\tSetConfig\x12:\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32%.degiro_connector.trading.Credentials\x12\x14\n\x0c\x61uto_connect\x18\x02 \x01(\x08\"u\n\x0c\x43onfirmOrder\x12\x35\n\x0f\x63onfirmation_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x05order\x18\x02 \x01(\x0b\x32\x1f.degiro_connector.trading.Order\"\xb3\x05\n\rProductSearch\x12\x45\n\x05\x62onds\x18\x01 \x01(\x0b\x32\x34.degiro_connector.trading.ProductSearch.RequestBondsH\x00\x12\x43\n\x04\x65tfs\x18\x02 \x01(\x0b\x32\x33.degiro_connector.trading.ProductSearch.RequestETFsH\x00\x12\x45\n\x05\x66unds\x18\x03 \x01(\x0b\x32\x34.degiro_connector.trading.ProductSearch.RequestFundsH\x00\x12I\n\x07\x66utures\x18\x04 \x01(\x0b\x32\x36.degiro_connector.trading.ProductSearch.RequestFuturesH\x00\x12O\n\nleverageds\x18\x05 \x01(\x0b\x32\x39.degiro_connector.trading.ProductSearch.RequestLeveragedsH\x00\x12G\n\x06lookup\x18\x06 \x01(\x0b\x32\x35.degiro_connector.trading.ProductSearch.RequestLookupH\x00\x12I\n\x07options\x18\x07 \x01(\x0b\x32\x36.degiro_connector.trading.ProductSearch.RequestOptionsH\x00\x12G\n\x06stocks\x18\x08 \x01(\x0b\x32\x35.degiro_connector.trading.ProductSearch.RequestStocksH\x00\x12K\n\x08warrants\x18\t \x01(\x0b\x32\x37.degiro_connector.trading.ProductSearch.RequestWarrantsH\x00\x42\t\n\x07request2\xcf\x13\n\x0cTradingRelay\x12u\n\rconfirm_order\x12,.degiro_connector.trading_relay.ConfirmOrder\x1a\x34.degiro_connector.trading.Order.ConfirmationResponse\"\x00\x12j\n\x0eproduct_search\x12-.degiro_connector.trading_relay.ProductSearch\x1a\'.degiro_connector.trading.ProductSearch\"\x00\x12U\n\nset_config\x12).degiro_connector.trading_relay.SetConfig\x1a\x1a.google.protobuf.BoolValue\"\x00\x12\x62\n\x0b\x63heck_order\x12\x1f.degiro_connector.trading.Order\x1a\x30.degiro_connector.trading.Order.CheckingResponse\"\x00\x12\x41\n\x07\x63onnect\x12\x16.google.protobuf.Empty\x1a\x1c.google.protobuf.StringValue\"\x00\x12J\n\x0c\x64\x65lete_order\x12\x1c.google.protobuf.StringValue\x1a\x1a.google.protobuf.BoolValue\"\x00\x12\x45\n\x10get_account_info\x12\x16.google.protobuf.Empty\x1a\x17.google.protobuf.Struct\"\x00\x12v\n\x14get_account_overview\x12\x31.degiro_connector.trading.AccountOverview.Request\x1a).degiro_connector.trading.AccountOverview\"\x00\x12Z\n\nget_agenda\x12(.degiro_connector.trading.Agenda.Request\x1a .degiro_connector.trading.Agenda\"\x00\x12}\n\x17get_cash_account_report\x12\x33.degiro_connector.trading.CashAccountReport.Request\x1a+.degiro_connector.trading.CashAccountReport\"\x00\x12G\n\x12get_client_details\x12\x16.google.protobuf.Empty\x1a\x17.google.protobuf.Struct\"\x00\x12_\n\x13get_company_profile\x12\x1c.google.protobuf.StringValue\x1a(.degiro_connector.trading.CompanyProfile\"\x00\x12]\n\x12get_company_ratios\x12\x1c.google.protobuf.StringValue\x1a\'.degiro_connector.trading.CompanyRatios\"\x00\x12?\n\nget_config\x12\x16.google.protobuf.Empty\x1a\x17.google.protobuf.Struct\"\x00\x12U\n\x13get_favourites_list\x12\x16.google.protobuf.Empty\x1a$.degiro_connector.trading.Favourites\"\x00\x12i\n\x18get_financial_statements\x12\x1c.google.protobuf.StringValue\x1a-.degiro_connector.trading.FinancialStatements\"\x00\x12g\n\x0fget_latest_news\x12,.degiro_connector.trading.LatestNews.Request\x1a$.degiro_connector.trading.LatestNews\"\x00\x12q\n\x13get_news_by_company\x12/.degiro_connector.trading.NewsByCompany.Request\x1a\'.degiro_connector.trading.NewsByCompany\"\x00\x12p\n\x12get_orders_history\x12/.degiro_connector.trading.OrdersHistory.Request\x1a\'.degiro_connector.trading.OrdersHistory\"\x00\x12_\n\x13get_products_config\x12\x16.google.protobuf.Empty\x1a..degiro_connector.trading.ProductSearch.Config\"\x00\x12m\n\x11get_products_info\x12..degiro_connector.trading.ProductsInfo.Request\x1a&.degiro_connector.trading.ProductsInfo\"\x00\x12Z\n\x14get_top_news_preview\x12\x16.google.protobuf.Empty\x1a(.degiro_connector.trading.TopNewsPreview\"\x00\x12\x82\x01\n\x18get_transactions_history\x12\x35.degiro_connector.trading.TransactionsHistory.Request\x1a-.degiro_connector.trading.TransactionsHistory\"\x00\x12^\n\nget_update\x12,.degiro_connector.trading.Update.RequestList\x1a .degiro_connector.trading.Update\"\x00\x12>\n\x06logout\x12\x16.google.protobuf.Empty\x1a\x1a.google.protobuf.BoolValue\"\x00\x12M\n\x0cupdate_order\x12\x1f.degiro_connector.trading.Order\x1a\x1a.google.protobuf.BoolValue\"\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,degiro__connector_dot_trading_dot_models_dot_trading__pb2.DESCRIPTOR,])




_SETCONFIG = _descriptor.Descriptor(
  name='SetConfig',
  full_name='degiro_connector.trading_relay.SetConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='credentials', full_name='degiro_connector.trading_relay.SetConfig.credentials', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_connect', full_name='degiro_connector.trading_relay.SetConfig.auto_connect', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=318,
)


_CONFIRMORDER = _descriptor.Descriptor(
  name='ConfirmOrder',
  full_name='degiro_connector.trading_relay.ConfirmOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirmation_id', full_name='degiro_connector.trading_relay.ConfirmOrder.confirmation_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order', full_name='degiro_connector.trading_relay.ConfirmOrder.order', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=437,
)


_PRODUCTSEARCH = _descriptor.Descriptor(
  name='ProductSearch',
  full_name='degiro_connector.trading_relay.ProductSearch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bonds', full_name='degiro_connector.trading_relay.ProductSearch.bonds', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etfs', full_name='degiro_connector.trading_relay.ProductSearch.etfs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funds', full_name='degiro_connector.trading_relay.ProductSearch.funds', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='futures', full_name='degiro_connector.trading_relay.ProductSearch.futures', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leverageds', full_name='degiro_connector.trading_relay.ProductSearch.leverageds', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lookup', full_name='degiro_connector.trading_relay.ProductSearch.lookup', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='degiro_connector.trading_relay.ProductSearch.options', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stocks', full_name='degiro_connector.trading_relay.ProductSearch.stocks', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warrants', full_name='degiro_connector.trading_relay.ProductSearch.warrants', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='request', full_name='degiro_connector.trading_relay.ProductSearch.request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=440,
  serialized_end=1131,
)

_SETCONFIG.fields_by_name['credentials'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._CREDENTIALS
_CONFIRMORDER.fields_by_name['confirmation_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONFIRMORDER.fields_by_name['order'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDER
_PRODUCTSEARCH.fields_by_name['bonds'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTBONDS
_PRODUCTSEARCH.fields_by_name['etfs'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTETFS
_PRODUCTSEARCH.fields_by_name['funds'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTFUNDS
_PRODUCTSEARCH.fields_by_name['futures'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTFUTURES
_PRODUCTSEARCH.fields_by_name['leverageds'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTLEVERAGEDS
_PRODUCTSEARCH.fields_by_name['lookup'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTLOOKUP
_PRODUCTSEARCH.fields_by_name['options'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTOPTIONS
_PRODUCTSEARCH.fields_by_name['stocks'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTSTOCKS
_PRODUCTSEARCH.fields_by_name['warrants'].message_type = degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_REQUESTWARRANTS
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['bonds'])
_PRODUCTSEARCH.fields_by_name['bonds'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['etfs'])
_PRODUCTSEARCH.fields_by_name['etfs'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['funds'])
_PRODUCTSEARCH.fields_by_name['funds'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['futures'])
_PRODUCTSEARCH.fields_by_name['futures'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['leverageds'])
_PRODUCTSEARCH.fields_by_name['leverageds'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['lookup'])
_PRODUCTSEARCH.fields_by_name['lookup'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['options'])
_PRODUCTSEARCH.fields_by_name['options'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['stocks'])
_PRODUCTSEARCH.fields_by_name['stocks'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
_PRODUCTSEARCH.oneofs_by_name['request'].fields.append(
  _PRODUCTSEARCH.fields_by_name['warrants'])
_PRODUCTSEARCH.fields_by_name['warrants'].containing_oneof = _PRODUCTSEARCH.oneofs_by_name['request']
DESCRIPTOR.message_types_by_name['SetConfig'] = _SETCONFIG
DESCRIPTOR.message_types_by_name['ConfirmOrder'] = _CONFIRMORDER
DESCRIPTOR.message_types_by_name['ProductSearch'] = _PRODUCTSEARCH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetConfig = _reflection.GeneratedProtocolMessageType('SetConfig', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIG,
  '__module__' : 'degiro_connector.trading.models.trading_relay_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading_relay.SetConfig)
  })
_sym_db.RegisterMessage(SetConfig)

ConfirmOrder = _reflection.GeneratedProtocolMessageType('ConfirmOrder', (_message.Message,), {
  'DESCRIPTOR' : _CONFIRMORDER,
  '__module__' : 'degiro_connector.trading.models.trading_relay_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading_relay.ConfirmOrder)
  })
_sym_db.RegisterMessage(ConfirmOrder)

ProductSearch = _reflection.GeneratedProtocolMessageType('ProductSearch', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTSEARCH,
  '__module__' : 'degiro_connector.trading.models.trading_relay_pb2'
  # @@protoc_insertion_point(class_scope:degiro_connector.trading_relay.ProductSearch)
  })
_sym_db.RegisterMessage(ProductSearch)



_TRADINGRELAY = _descriptor.ServiceDescriptor(
  name='TradingRelay',
  full_name='degiro_connector.trading_relay.TradingRelay',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1134,
  serialized_end=3645,
  methods=[
  _descriptor.MethodDescriptor(
    name='confirm_order',
    full_name='degiro_connector.trading_relay.TradingRelay.confirm_order',
    index=0,
    containing_service=None,
    input_type=_CONFIRMORDER,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDER_CONFIRMATIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='product_search',
    full_name='degiro_connector.trading_relay.TradingRelay.product_search',
    index=1,
    containing_service=None,
    input_type=_PRODUCTSEARCH,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='set_config',
    full_name='degiro_connector.trading_relay.TradingRelay.set_config',
    index=2,
    containing_service=None,
    input_type=_SETCONFIG,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='check_order',
    full_name='degiro_connector.trading_relay.TradingRelay.check_order',
    index=3,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDER,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDER_CHECKINGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='connect',
    full_name='degiro_connector.trading_relay.TradingRelay.connect',
    index=4,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='delete_order',
    full_name='degiro_connector.trading_relay.TradingRelay.delete_order',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_account_info',
    full_name='degiro_connector.trading_relay.TradingRelay.get_account_info',
    index=6,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_struct__pb2._STRUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_account_overview',
    full_name='degiro_connector.trading_relay.TradingRelay.get_account_overview',
    index=7,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ACCOUNTOVERVIEW_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ACCOUNTOVERVIEW,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_agenda',
    full_name='degiro_connector.trading_relay.TradingRelay.get_agenda',
    index=8,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._AGENDA_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._AGENDA,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_cash_account_report',
    full_name='degiro_connector.trading_relay.TradingRelay.get_cash_account_report',
    index=9,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._CASHACCOUNTREPORT_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._CASHACCOUNTREPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_client_details',
    full_name='degiro_connector.trading_relay.TradingRelay.get_client_details',
    index=10,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_struct__pb2._STRUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_profile',
    full_name='degiro_connector.trading_relay.TradingRelay.get_company_profile',
    index=11,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._COMPANYPROFILE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_ratios',
    full_name='degiro_connector.trading_relay.TradingRelay.get_company_ratios',
    index=12,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._COMPANYRATIOS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_config',
    full_name='degiro_connector.trading_relay.TradingRelay.get_config',
    index=13,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_struct__pb2._STRUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_favourites_list',
    full_name='degiro_connector.trading_relay.TradingRelay.get_favourites_list',
    index=14,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._FAVOURITES,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_financial_statements',
    full_name='degiro_connector.trading_relay.TradingRelay.get_financial_statements',
    index=15,
    containing_service=None,
    input_type=google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._FINANCIALSTATEMENTS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_latest_news',
    full_name='degiro_connector.trading_relay.TradingRelay.get_latest_news',
    index=16,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._LATESTNEWS_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._LATESTNEWS,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_news_by_company',
    full_name='degiro_connector.trading_relay.TradingRelay.get_news_by_company',
    index=17,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._NEWSBYCOMPANY_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._NEWSBYCOMPANY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_orders_history',
    full_name='degiro_connector.trading_relay.TradingRelay.get_orders_history',
    index=18,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDERSHISTORY_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDERSHISTORY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_products_config',
    full_name='degiro_connector.trading_relay.TradingRelay.get_products_config',
    index=19,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSEARCH_CONFIG,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_products_info',
    full_name='degiro_connector.trading_relay.TradingRelay.get_products_info',
    index=20,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSINFO_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._PRODUCTSINFO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_top_news_preview',
    full_name='degiro_connector.trading_relay.TradingRelay.get_top_news_preview',
    index=21,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._TOPNEWSPREVIEW,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_transactions_history',
    full_name='degiro_connector.trading_relay.TradingRelay.get_transactions_history',
    index=22,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._TRANSACTIONSHISTORY_REQUEST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._TRANSACTIONSHISTORY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='get_update',
    full_name='degiro_connector.trading_relay.TradingRelay.get_update',
    index=23,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._UPDATE_REQUESTLIST,
    output_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._UPDATE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='logout',
    full_name='degiro_connector.trading_relay.TradingRelay.logout',
    index=24,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='update_order',
    full_name='degiro_connector.trading_relay.TradingRelay.update_order',
    index=25,
    containing_service=None,
    input_type=degiro__connector_dot_trading_dot_models_dot_trading__pb2._ORDER,
    output_type=google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TRADINGRELAY)

DESCRIPTOR.services_by_name['TradingRelay'] = _TRADINGRELAY

# @@protoc_insertion_point(module_scope)



# IMPORTATION STANDARD
import requests
import logging
import time

# IMPORTATION THIRD PARTY
# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.quotecast.models.quotecast_pb2 import (
    Quotecast,
)
from degiro_connector.core.abstracts.abstract_action import AbstractAction


class ActionFetchData(AbstractAction):
    @classmethod
    def fetch_data(
        cls,
        session_id: str,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Quotecast:
        """Fetches data from the feed.
        Args:
            session_id (str):
                API's session id.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Raises:
            BrokenPipeError:
                A new "session_id" is required.
        Returns:
            Quotecast:
                json_data : raw JSON data string.
                metadata.response_datetime : reception timestamp.
                metadata.request_duration : request duration.
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = f"{urls.QUOTECAST}/{session_id}"

        request = requests.Request(method="GET", url=url)
        prepped = session.prepare_request(request=request)

        start_ns = time.perf_counter_ns()
        response = session.send(request=prepped, verify=False)
        # We could have used : response.elapsed.total_seconds()
        duration_ns = time.perf_counter_ns() - start_ns

        if response.text == '[{"m":"sr"}]':
            raise BrokenPipeError('A new "session_id" is required.')

        quotecast = Quotecast()
        quotecast.json_data = response.text
        # There is no "date" header returned
        # We could have used : response.cookies._now
        quotecast.metadata.response_datetime.GetCurrentTime()
        quotecast.metadata.request_duration.FromNanoseconds(duration_ns)

        return quotecast

    def call(self) -> Quotecast:
        session_id = self.connection_storage.session_id
        session = self.session_storage.session
        logger = self.logger

        return self.fetch_data(
            session_id=session_id,
            session=session,
            logger=logger,
        )



# IMPORTATION STANDARD
import logging
from typing import Dict, Union

# IMPORTATION THIRD PARTY
import requests
from google.protobuf import json_format

# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.core.abstracts.abstract_action import AbstractAction
from degiro_connector.trading.models.trading_pb2 import (
    Credentials,
    LatestNews,
)


class ActionGetLatestNews(AbstractAction):
    @staticmethod
    def latest_news_request_to_api(
        request: LatestNews.Request,
    ) -> dict:
        request_dict = {
            "offset": request.offset,
            "languages": request.languages,
            "limit": request.limit,
        }

        return request_dict

    @staticmethod
    def latest_news_to_grpc(payload: dict) -> LatestNews:
        latest_news = LatestNews()
        json_format.ParseDict(
            js_dict=payload["data"],
            message=latest_news,
            ignore_unknown_fields=False,
            descriptor_pool=None,
        )

        return latest_news

    @classmethod
    def get_latest_news(
        cls,
        request: LatestNews.Request,
        session_id: str,
        credentials: Credentials,
        raw: bool = False,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Union[LatestNews, Dict, None]:
        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = urls.LATEST_NEWS

        params = cls.latest_news_request_to_api(
            request=request,
        )
        params["intAccount"] = credentials.int_account
        params["sessionId"] = session_id

        http_request = requests.Request(method="GET", url=url, params=params)
        prepped = session.prepare_request(http_request)
        prepped.headers["cookie"] = "JSESSIONID=" + session_id

        response_raw = None

        try:
            response_raw = session.send(prepped, verify=False)
            response_raw.raise_for_status()
            response_dict = response_raw.json()

            if raw is True:
                return response_dict
            else:
                return cls.latest_news_to_grpc(
                    payload=response_dict,
                )
        except Exception as e:
            logger.fatal("error")
            logger.fatal(response_raw)
            logger.fatal(e)
            return None

    def call(
        self,
        request: LatestNews.Request,
        raw: bool = False,
    ) -> Union[LatestNews, Dict, None]:
        connection_storage = self.connection_storage
        session_id = connection_storage.session_id
        session = self.session_storage.session
        credentials = self.credentials
        logger = self.logger

        return self.get_latest_news(
            request=request,
            session_id=session_id,
            credentials=credentials,
            raw=raw,
            session=session,
            logger=logger,
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SetConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_TOKEN_FIELD_NUMBER: builtins.int
    AUTO_CONNECT_FIELD_NUMBER: builtins.int
    user_token: builtins.int = ...
    auto_connect: builtins.bool = ...
    def __init__(self,
        *,
        user_token : builtins.int = ...,
        auto_connect : builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"auto_connect",b"auto_connect",u"user_token",b"user_token"]) -> None: ...
global___SetConfig = SetConfig



# IMPORTATION STANDARD
import requests
import logging
from typing import Optional

# IMPORTATION THIRD PARTY
# IMPORTATION INTERNAL
import degiro_connector.core.constants.urls as urls
from degiro_connector.quotecast.models.quotecast_pb2 import (
    Quotecast,
)
from degiro_connector.core.abstracts.abstract_action import AbstractAction


class ActionSubscribe(AbstractAction):
    @staticmethod
    def quotecast_request_to_api(request: Quotecast.Request) -> str:
        payload = '{"controlData":"'
        for vwd_id in request.subscriptions:
            for metric_name in request.subscriptions[vwd_id]:
                payload += "a_req(" + vwd_id + "." + metric_name + ");"
        for vwd_id in request.unsubscriptions:
            for metric_name in request.unsubscriptions[vwd_id]:
                payload += "a_rel(" + vwd_id + "." + metric_name + ");"
        payload += '"}'

        return payload

    @classmethod
    def subscribe(
        cls,
        request: Quotecast.Request,
        session_id: str,
        session: requests.Session = None,
        logger: logging.Logger = None,
    ) -> Optional[bool]:
        """Adds/removes metric from the data-stream.
        Args:
            request (QuotecastAPI.Request):
                List of subscriptions & unsubscriptions to do.
                Example :
                    request = Quotecast.Request()
                    request.subscriptions['360015751'].extend([
                        'LastPrice',
                        'LastVolume',
                    ])
                    request.subscriptions['AAPL.BATS,E'].extend([
                        'LastPrice',
                        'LastVolume',
                    ])
                    request.unsubscriptions['360015751'].extend([
                        'LastPrice',
                        'LastVolume',
                    ])
            session_id (str):
                API's session id.
            session (requests.Session, optional):
                This object will be generated if None.
                Defaults to None.
            logger (logging.Logger, optional):
                This object will be generated if None.
                Defaults to None.
        Raises:
            BrokenPipeError:
                A new "session_id" is required.
        Returns:
            bool:
                Whether or not the subscription succeeded.
        """

        if logger is None:
            logger = cls.build_logger()
        if session is None:
            session = cls.build_session()

        url = urls.QUOTECAST
        url = f"{url}/{session_id}"
        data = cls.quotecast_request_to_api(request=request)

        logger.info("subscribe:data %s", data[:100])

        session_request = requests.Request(method="POST", url=url, data=data)
        prepped = session.prepare_request(request=session_request)
        response_raw = None

        try:
            response_raw = session.send(request=prepped, verify=False)
            response_raw.raise_for_status()

            if response_raw.text == '[{"m":"sr"}]':
                raise BrokenPipeError('A new "session_id" is required.')
            else:
                return True
        except Exception as e:
            logger.fatal(e)
            return None

    def call(self, request: Quotecast.Request) -> Optional[bool]:
        session_id = self.connection_storage.session_id
        session = self.session_storage.session
        logger = self.logger

        return self.subscribe(
            request=request,
            session_id=session_id,
            session=session,
            logger=logger,
        )
